==> ep-framework-wordpress-1.5.5-1025a3.tar: src/Plugin/Core/Assets.php <==
<?php
namespace Ep\Wp\Plugin\Core;

use _WP_Dependency;
use Ep\View\Helper\AssetUrl;
use Ep\Wp\Plugin\PluginInterface;

/**
 * Omogućava dodavanje Asseta iz manifesta u WordPress.
 *
 * @package Ep\Wp\Plugin\Core
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
final class Assets implements PluginInterface
{
    /** @var AssetUrl */
    protected $assetUrl;

    /**
     * Assets constructor.
     *
     * @param AssetUrl $assetUrl
     */
    public function __construct(AssetUrl $assetUrl)
    {
        $this->assetUrl = $assetUrl;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('ep_asset_url', [$this, 'ep_asset_url']);
        add_action('wp_enqueue_scripts', [$this, 'wp_enqueue_scripts'], PHP_INT_MAX);
        add_action('admin_enqueue_scripts', [$this, 'wp_enqueue_scripts'], PHP_INT_MAX);
    }

    public function ep_asset_url($asset)
    {
        $assetUrl = $this->assetUrl;
        return '//' . $_SERVER['HTTP_HOST'] . preg_replace('#/wp(/wp-admin)?#', '', $assetUrl($asset));
    }

    /**
     * Zamijenjuje url-ove stvarnima.
     */
    public function wp_enqueue_scripts()
    {
        global $wp_scripts, $wp_styles;

        foreach ([$wp_scripts, $wp_styles] as $obj) {
            foreach ($obj->registered as $script) {
                if (preg_match('#(/wp/){2,}#', $script->src)) {
                    $script->src = preg_replace('#(/wp/){2,}#', '/wp/', $script->src);
                }

                /** @var _WP_Dependency $script */
                if ($script->ver === 'ep-asset') {
                    $script->src = $this->ep_asset_url($script->src);
                    $script->ver = null;
                }
            }
        }
    }
}

==> ep-framework-wordpress-2.1.0-a1654b.tar: src/Plugin/Core/Assets.php <==
<?php
namespace Ep\Wp\Plugin\Core;

use _WP_Dependency;
use Ep\View\Helper\AssetUrl;
use Ak\Wp\Plugin\PluginInterface;

/**
 * Omogućava dodavanje Asseta iz manifesta u WordPress.
 *
 * @package Ep\Wp\Plugin\Core
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
final class Assets implements PluginInterface
{
    /** @var AssetUrl */
    protected $assetUrl;

    /**
     * Assets constructor.
     *
     * @param AssetUrl $assetUrl
     */
    public function __construct(AssetUrl $assetUrl)
    {
        $this->assetUrl = $assetUrl;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     */
    public function attach(): void
    {
        add_filter('ep_asset_url', [$this, 'ep_asset_url']);
        add_action('wp_enqueue_scripts', [$this, 'wp_enqueue_scripts'], PHP_INT_MAX);
        add_action('admin_enqueue_scripts', [$this, 'wp_enqueue_scripts'], PHP_INT_MAX);
    }

    public function ep_asset_url($asset)
    {
        $assetUrl = $this->assetUrl;
        return '//' . $_SERVER['HTTP_HOST'] . preg_replace('#/wp(/wp-admin)?#', '', $assetUrl($asset));
    }

    /**
     * Zamijenjuje url-ove stvarnima.
     */
    public function wp_enqueue_scripts()
    {
        global $wp_scripts, $wp_styles;

        foreach ([$wp_scripts, $wp_styles] as $obj) {
            foreach ($obj->registered as $script) {
                if (preg_match('#(/wp/){2,}#', $script->src)) {
                    $script->src = preg_replace('#(/wp/){2,}#', '/wp/', $script->src);
                }

                /** @var _WP_Dependency $script */
                if ($script->ver === 'ep-asset') {
                    $script->src = $this->ep_asset_url($script->src);
                    $script->ver = null;
                }
            }
        }
    }
}
